"""Interfaces with PyPI and Python modules for running the module fast."""
from .usages import Usages


def main():
    """Runs Usages' method `runType()`"""
    Usages()


if __name__ == "__main__":
    main()
